@@ -90,7 +90,6 @@ import com.openexchange.exception.OXException;
 import com.openexchange.java.DefaultHashKeyGenerator;
 import com.openexchange.java.HashKeyGenerator;
 import com.openexchange.java.HashKeyMap;
-import com.openexchange.log.Log;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.tools.servlet.http.Tools;
 
@@ -101,8 +100,7 @@ import com.openexchange.tools.servlet.http.Tools;
  */
 public final class HttpServletRequestImpl implements HttpServletRequest, Parameterizable {
 
-    private static final org.apache.commons.logging.Log LOG =
-        Log.valueOf(com.openexchange.log.LogFactory.getLog(HttpServletRequestImpl.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HttpServletRequestImpl.class);
 
     /**
      * The name of the "Content-Type" header.
@@ -416,7 +414,7 @@ public final class HttpServletRequestImpl implements HttpServletRequest, Paramet
             try {
                 ct = new ContentType(value);
             } catch (final OXException e) {
-                com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(HttpServletRequestImpl.class)).error(
+                org.slf4j.LoggerFactory.getLogger(HttpServletRequestImpl.class).error(
                     e.getMessage(),
                     e);
                 throw new AJPv13Exception(AJPCode.INVALID_CONTENT_TYPE, true, e, value);
@@ -1001,9 +999,7 @@ public final class HttpServletRequestImpl implements HttpServletRequest, Paramet
 
     @Override
     public boolean isUserInRole(final String role) {
-        if (LOG.isWarnEnabled()) {
-            LOG.warn("Method isUserInRole() is not implemented in HttpServletRequestWrapper, yet!");
-        }
+        LOG.warn("Method isUserInRole() is not implemented in HttpServletRequestWrapper, yet!");
         return false;
     }
 
@@ -1216,7 +1212,7 @@ public final class HttpServletRequestImpl implements HttpServletRequest, Paramet
         try {
             return Tools.parseHeaderDate(headerValue).getTime();
         } catch (final ParseException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw new IllegalArgumentException(e.getMessage());
         }
     }
