@@ -75,7 +75,7 @@ import com.openexchange.tools.regex.MatcherReplacer;
  */
 public class ServletResponseWrapper implements ServletResponse {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ServletResponseWrapper.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ServletResponseWrapper.class);
 
     public static final int OUTPUT_NOT_SELECTED = -1;
 
@@ -267,7 +267,7 @@ public class ServletResponseWrapper implements ServletResponse {
                     writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(servletOutputStream, getCharacterEncoding())), true);
                 }
             } catch (final UnsupportedEncodingException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.error("", e);
             }
         } else if (outputSelection == OUTPUT_STREAM && servletOutputStream != null) {
             servletOutputStream.resetBuffer();
@@ -399,7 +399,7 @@ public class ServletResponseWrapper implements ServletResponse {
                     writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(servletOutputStream, getCharacterEncoding())), true);
                 }
             } catch (final UnsupportedEncodingException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.error("", e);
             }
         }
     }
