@@ -49,23 +49,19 @@
 
 package com.openexchange.ajp13.coyote;
 
-import static com.openexchange.ajp13.coyote.CookieWrapper.wrapper;
 import gnu.trove.map.TIntObjectMap;
 import gnu.trove.map.hash.TIntObjectHashMap;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
-import java.io.Writer;
 import java.text.DateFormat;
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.Iterator;
-import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.List;
@@ -78,24 +74,22 @@ import javax.servlet.ServletOutputStream;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
-import org.apache.commons.logging.Log;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.SessionServlet;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13RequestHandler;
+import com.openexchange.ajp13.AJPv13ServiceRegistry;
 import com.openexchange.ajp13.AJPv13ServletOutputStream;
-import com.openexchange.ajp13.Services;
 import com.openexchange.ajp13.servlet.ServletResponseWrapper;
 import com.openexchange.ajp13.servlet.http.HttpDateFormatRegistry;
 import com.openexchange.ajp13.util.CharsetValidator;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ServerConfig;
-import com.openexchange.java.AsciiWriter;
 import com.openexchange.java.Charsets;
-import com.openexchange.java.Streams;
+import com.openexchange.java.StringAllocator;
+import com.openexchange.server.impl.Version;
 import com.openexchange.session.Session;
 import com.openexchange.tools.regex.MatcherReplacer;
-import com.openexchange.version.Version;
 
 /**
  * {@link HttpServletResponseImpl}
@@ -104,9 +98,8 @@ import com.openexchange.version.Version;
  */
 public final class HttpServletResponseImpl implements HttpServletResponse {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(HttpServletResponseImpl.class);
-
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(ServletResponseWrapper.class);
 
     public static final int OUTPUT_NOT_SELECTED = -1;
 
@@ -122,7 +115,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
             synchronized (ServletResponseWrapper.class) {
                 tmp = defaultCharset;
                 if (tmp == null) {
-                    final ConfigurationService service = Services.getService(ConfigurationService.class);
+                    final ConfigurationService service = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
                     if (null == service) {
                         return "UTF-8";
                     }
@@ -180,7 +173,6 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         STATUS_MSGS.put(415, "Unsupported Media Type");
         STATUS_MSGS.put(416, "Requested Range Not Satisfiable");
         STATUS_MSGS.put(417, "Expectation Failed");
-        STATUS_MSGS.put(429, "Too Many Requests");
         STATUS_MSGS.put(500, "Internal Server Error");
         STATUS_MSGS.put(501, "Not Implemented");
         STATUS_MSGS.put(502, "Bad Gateway");
@@ -202,7 +194,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
      */
     private static final Set<String> SINGLE_VALUE_HEADERS = Constants.SINGLE_VALUE_HEADERS;
 
-    private final Set<CookieWrapper> cookies;
+    private final Set<Cookie> cookies;
 
     private String statusMsg;
 
@@ -222,7 +214,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     private Locale locale;
 
-    private volatile boolean committed;
+    private boolean committed;
 
     private int bufferSize;
 
@@ -241,11 +233,11 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         super();
         headers = new HashMap<String, List<String>>(16);
         outputSelection = OUTPUT_NOT_SELECTED;
-        cookies = new LinkedHashSet<CookieWrapper>(8);
+        cookies = new LinkedHashSet<Cookie>();
         status = HttpServletResponse.SC_OK;
         statusMsg = "OK";
         this.ajpProcessor = ajpProcessor;
-        final ConfigurationService cs = Services.getService(ConfigurationService.class);
+        final ConfigurationService cs = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
         httpOnly = (null != cs && cs.getBoolProperty(ServerConfig.Property.COOKIE_HTTP_ONLY.getPropertyName(), true));
     }
 
@@ -291,17 +283,17 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         if (contentType == null) {
             return;
         }
-        final Matcher matcher = CONTENT_TYPE_CHARSET_PARAM.matcher(contentType);
-        if (matcher.find()) {
+        final Matcher m = CONTENT_TYPE_CHARSET_PARAM.matcher(contentType);
+        if (m.find()) {
             /*
              * Check if getWriter() was already called
              */
-            if (outputSelection == OUTPUT_WRITER && !characterEncoding.equalsIgnoreCase(matcher.group(2))) {
+            if (outputSelection == OUTPUT_WRITER && !characterEncoding.equalsIgnoreCase(m.group(2))) {
                 throw new IllegalStateException("\"getWriter()\" has already been called. Not allowed to change its encoding afterwards");
             }
             do {
-                setCharacterEncoding(matcher.group(2));
-            } while (matcher.find());
+                setCharacterEncoding(m.group(2));
+            } while (m.find());
         } else if (characterEncoding == null) {
             /*
              * Corresponding to rfc
@@ -324,11 +316,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     @Override
     public void setContentLength(final int contentLength) {
-        if (contentLength < 0) {
-            headers.remove(CONTENT_LENGTH);
-        } else {
-            headers.put(CONTENT_LENGTH, Collections.singletonList(Integer.toString(contentLength)));
-        }
+        headers.put(CONTENT_LENGTH, Collections.singletonList(String.valueOf(contentLength)));
     }
 
     public int getContentLength() {
@@ -337,25 +325,11 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     @Override
     public void flushBuffer() throws IOException {
-        /*-
-         * Since PrintWriter simply delegates flush() invocation to underlying OutputStream,
-         * we can safely call ServletOutputStream.flush() directly.
-         *
-         * See implementation of flush() inside PrintWriter:
-         *    public void flush() {
-         *        try {
-         *        synchronized (lock) {
-         *        ensureOpen()
-         *        out.flush();
-         *        }
-         *        }
-         *        catch (IOException x) {
-         *        trouble = true;
-         *        }
-         *    }
-         */
-        Streams.flush(writer);
-        Streams.flush(servletOutputStream);
+        if (null == writer) {
+            servletOutputStream.flush();
+        } else {
+            writer.flush();
+        }
     }
 
     /**
@@ -435,7 +409,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     @Override
     public PrintWriter getWriter() throws UnsupportedEncodingException, IOException {
-        if (false && outputSelection == OUTPUT_STREAM) {
+        if (outputSelection == OUTPUT_STREAM) {
             throw new IllegalStateException("Servlet's OutputStream has already been selected as output");
         }
         if (null != writer) {
@@ -454,18 +428,16 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         /*
          * Check if getOutputSteam hasn't been called before
          */
-        if (false && outputSelection == OUTPUT_STREAM) {
+        if (outputSelection == OUTPUT_STREAM) {
             throw new IllegalStateException("Servlet's OutputStream has already been selected as output");
         }
         if (outputSelection == OUTPUT_NOT_SELECTED) {
             outputSelection = OUTPUT_WRITER;
         }
         if (bufferSize > 0) {
-            final Writer w = Charsets.isAsciiCharset(characterEncoding) ? new AsciiWriter(servletOutputStream) : new OutputStreamWriter(servletOutputStream, characterEncoding);
-            writer = new PrintWriter(w, false);
+            writer = new PrintWriter(new OutputStreamWriter(servletOutputStream, characterEncoding), false);
         } else {
-            final Writer w = Charsets.isAsciiCharset(characterEncoding) ? new AsciiWriter(servletOutputStream) : new OutputStreamWriter(servletOutputStream, characterEncoding);
-            writer = new PrintWriter(w, false);
+            writer = new PrintWriter(new OutputStreamWriter(servletOutputStream, characterEncoding), false);
         }
         return writer;
     }
@@ -634,7 +606,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         }
         final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(path);
         if (httpSessionId != null && sb.length() > 0) {
-            sb.append('/');
+            sb.append("/");
             sb.append(AJPv13RequestHandler.JSESSIONID_URI);
             sb.append(httpSessionId);
         }
@@ -664,12 +636,12 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     @Override
     public void addIntHeader(final String name, final int i) {
-        addHeader(name, Integer.toString(i));
+        addHeader(name, String.valueOf(i));
     }
 
     @Override
     public void addCookie(final Cookie cookie) {
-        cookies.add(wrapper(cookie));
+        cookies.add(cookie);
     }
 
     /**
@@ -678,29 +650,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
      * @param cookie The cookie to remove
      */
     public void removeCookie(final Cookie cookie) {
-        if (null == cookie) {
-            return;
-        }
-        cookies.remove(wrapper(cookie));
-    }
-
-    private static final List<List<String>> EMPTY_COOKIES = Collections.emptyList();
-
-    private static volatile Boolean filterByName;
-
-    private static boolean filterByName() {
-        Boolean tmp = filterByName;
-        if (null == tmp) {
-            synchronized (AjpProcessor.class) {
-                tmp = filterByName;
-                if (null == tmp) {
-                    final ConfigurationService service = Services.getService(ConfigurationService.class);
-                    tmp = Boolean.valueOf(null != service && service.getBoolProperty("com.openexchange.cookie.filterByName", false));
-                    filterByName = tmp;
-                }
-            }
-        }
-        return tmp.booleanValue();
+        cookies.remove(cookie);
     }
 
     /**
@@ -711,128 +661,52 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
      *
      * @return A two dimensional array of {@link String} containing the <tt>Set-Cookie</tt>/<tt>Set-Cookie2</tt> headers
      */
-    public List<List<String>> getFormatedCookies() {
+    public String[][] getFormatedCookies() {
+        final String[][] retval = new String[1][];
         final int cookiesSize = cookies.size();
-        if (cookiesSize <= 0) {
-            return EMPTY_COOKIES;
-        }
-        // Write cookies
-        final Collection<CookieWrapper> iterateMe;
-        if (filterByName()) {
-            // Check for duplicate named cookies
-            final Map<String, CookieWrapper> checkedCookies = new LinkedHashMap<String, CookieWrapper>(cookiesSize);
-            for (final CookieWrapper wrapper : cookies) {
-                /*final Cookie prev = */checkedCookies.put(wrapper.getCookie().getName(), wrapper);
-                // Already existing; decide which one to keep or to merge
-                // By now: Keep the newer one (cookies is a LinkedHashSet that keeps order)
-                /*-
-                 *
-                if (null != prev) {
-                    if (0 == prev.getMaxAge()) {
-                        // First indeciates delete
-                        if (0 == cookie.getMaxAge()) {
-                            // Keep previous one
-                            names.put(cookie.getName(), prev);
-                        }
-                    } else {
-                        // First i
-
-                    }
-                }
-                */
+        final String[] list = new String[cookiesSize];
+        if (cookiesSize > 0) {
+            final HttpServletRequestImpl request = ajpProcessor.getRequest();
+            final String userAgent = request.getHeader("User-Agent");
+            final Iterator<Cookie> iter = cookies.iterator();
+            final StringBuilder composer = new StringBuilder(32);
+            list[0] = getFormattedCookie(iter.next(), userAgent, composer, httpOnly);
+            for (int i = 1; i < cookiesSize; i++) {
+                composer.setLength(0);
+                list[i] = getFormattedCookie(iter.next(), userAgent, composer, httpOnly);
             }
-            iterateMe = checkedCookies.values();
-        } else {
-            // Write to list
-            iterateMe = cookies;
         }
-        // Write to list
-        final List<String> list = new ArrayList<String>(cookiesSize);
-        final String userAgent = ajpProcessor.getRequest().getHeader("User-Agent");
-        final StringBuilder strBuilder = new StringBuilder(32);
-        for (final CookieWrapper wrapper : iterateMe) {
-            list.add(getFormattedCookie(wrapper.getCookie(), userAgent, strBuilder, httpOnly));
-        }
-        final List<List<String>> retval = new ArrayList<List<String>>(1);
-        retval.add(list);
+        retval[0] = list;
         return retval;
     }
 
-    private static volatile String[] cookieParams;
-
-    private static String[] cookieParams() {
-        String[] tmp = cookieParams;
-        if (null == tmp) {
-            synchronized (HttpServletResponseImpl.class) {
-                tmp = cookieParams;
-                if (null == tmp) {
-                    final ConfigurationService service = Services.getService(ConfigurationService.class);
-                    if (null == service) {
-                        tmp = new String[] { "; expires=", "; version=", "; path=", "; domain=", "; secure" };
-                    } else {
-                        tmp = new String[5];
-                        final StringBuilder sb = new StringBuilder(16).append("; ");
-                        int pos = 0;
-
-                        String name = service.getProperty("com.openexchange.cookie.expires.name", "expires");
-                        tmp[pos++] = sb.append(name).append('=').toString();
-
-                        name = service.getProperty("com.openexchange.cookie.version.name", "version");
-                        sb.setLength(2);
-                        tmp[pos++] = sb.append(name).append('=').toString();
-
-                        name = service.getProperty("com.openexchange.cookie.path.name", "path");
-                        sb.setLength(2);
-                        tmp[pos++] = sb.append(name).append('=').toString();
-
-                        name = service.getProperty("com.openexchange.cookie.domain.name", "domain");
-                        sb.setLength(2);
-                        tmp[pos++] = sb.append(name).append('=').toString();
-
-                        name = service.getProperty("com.openexchange.cookie.secure.name", "secure");
-                        sb.setLength(2);
-                        tmp[pos++] = sb.append(name).toString();
-                    }
-                    cookieParams = tmp;
-                }
-            }
-        }
-        return tmp;
-    }
+    private static final String[] COOKIE_PARAMS = { "; expires=", "; version=", "; path=", "; domain=", "; secure" };
 
     /**
      * Gets the HTTP header format for specified instance of {@link Cookie}
      *
      * @param cookie The cookie whose HTTP header format shall be returned
-     * @param strBuilder A string builder instance
+     * @param composer A string builder used for composing
      * @return A string representing the HTTP header format
      */
-    private static final String getFormattedCookie(final Cookie cookie, final String userAgent, final StringBuilder strBuilder, final boolean httpOnly) {
-        strBuilder.setLength(0);
-        strBuilder.append(cookie.getName()).append('=');
-        strBuilder.append(cookie.getValue());
+    private static final String getFormattedCookie(final Cookie cookie, final String userAgent, final StringBuilder composer, final boolean httpOnly) {
+        composer.append(cookie.getName()).append('=');
+        composer.append(cookie.getValue());
         final int maxAge = cookie.getMaxAge();
         if (maxAge >= 0) {
-            HttpDateFormatRegistry.getInstance().appendCookieMaxAge(maxAge, userAgent, strBuilder);
+            HttpDateFormatRegistry.getInstance().appendCookieMaxAge(maxAge, userAgent, composer);
         }
-        final String[] cookieParams = cookieParams();
         if (cookie.getVersion() > 0) {
-            strBuilder.append(cookieParams[1]).append(cookie.getVersion());
+            composer.append(COOKIE_PARAMS[1]).append(cookie.getVersion());
         }
-        {
-            final String path = cookie.getPath();
-            if (!isEmpty(path)) {
-                strBuilder.append(cookieParams[2]).append(path);
-            }
+        if (cookie.getPath() != null) {
+            composer.append(COOKIE_PARAMS[2]).append(cookie.getPath());
         }
-        {
-            final String domain = cookie.getDomain();
-            if (!isEmpty(domain)) {
-                strBuilder.append(cookieParams[3]).append(domain);
-            }
+        if (cookie.getDomain() != null) {
+            composer.append(COOKIE_PARAMS[3]).append(cookie.getDomain());
         }
         if (cookie.getSecure()) {
-            strBuilder.append(cookieParams[4]);
+            composer.append(COOKIE_PARAMS[4]);
         }
         /*-
          * TODO: HttpOnly currently cannot be set in Cookie class, thus we do it hard-coded here.
@@ -841,35 +715,20 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
          * Append HttpOnly flag
          */
         if (httpOnly /* && maxAge > 0 */) {
-            strBuilder.append("; HttpOnly");
+            composer.append("; HttpOnly");
         }
-        if (DEBUG) {
-            LOG.debug("Cookie: " + strBuilder.toString());
-        }
-        return strBuilder.toString();
-    }
-
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
+        return composer.toString();
     }
 
     @Override
     public void addHeader(final String name, final String value) {
-        if (SINGLE_VALUE_HEADERS.contains(name)) {
+        final List<String> prevValues = headers.get(name);
+        if (null == prevValues || SINGLE_VALUE_HEADERS.contains(name)) {
             headers.put(name, Collections.singletonList(value));
         } else {
             /*
              * Header may carry multiple values
              */
-            final List<String> prevValues = headers.get(name);
             if (null == prevValues) {
                 headers.put(name, newLinkedList(value));
             } else {
@@ -878,12 +737,13 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         }
     }
 
-    private static List<String> newLinkedList(final String initialValue) {
-        final List<String> list = new LinkedList<String>();
+    private static LinkedList<String> newLinkedList(final String initialValue) {
+        final LinkedList<String> list = new LinkedList<String>();
         list.add(initialValue);
         return list;
     }
 
+    @Override
     public int getStatus() {
         return status;
     }
@@ -915,7 +775,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
 
     @Override
     public void setIntHeader(final String name, final int i) {
-        setHeader(name, Integer.toString(i));
+        setHeader(name, String.valueOf(i));
     }
 
     @Override
@@ -934,18 +794,21 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         return headers.size();
     }
 
-    public final Iterator<String> getHeaderNames() {
-        return headers.keySet().iterator();
+    @Override
+    public final Collection<String> getHeaderNames() {
+        return headers.keySet();
     }
 
     public final Set<Map.Entry<String, List<String>>> getHeaderEntrySet() {
         return headers.entrySet();
     }
 
-    public Enumeration<?> getHeaders(final String name) {
-        return makeEnumeration(headers.get(name));
+    @Override
+    public Collection<String> getHeaders(final String name) {
+        return headers.get(name);
     }
 
+    @Override
     public final String getHeader(final String name) {
         if (!containsHeader(name)) {
             return null;
@@ -953,8 +816,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         final StringBuilder retval = new StringBuilder(128);
         final List<String> list = headers.get(name);
         retval.append(list.get(0));
-        final int len = list.size();
-        for (int i = 1; i < len; i++) {
+        for (int i = 1, len = list.size(); i < len; i++) {
             retval.append(',').append(list.get(i));
         }
         return retval.toString();
@@ -975,8 +837,9 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
      * @param status The status to set
      * @param statusMsg The (optional) status message or <code>null</code>
      * @return The error message in bytes
+     * @throws IOException If an I/O error occurs
      */
-    public final byte[] composeAndSetError(final int status, final String statusMsg) {
+    public final byte[] composeAndSetError(final int status, final String statusMsg) throws IOException {
         this.status = status;
         this.statusMsg = statusMsg == null ? STATUS_MSGS.get(status) : statusMsg;
         String desc = STATUS_DESC.containsKey(this.status) ? STATUS_DESC.get(this.status) : ERR_DESC_NOT_AVAILABLE;
@@ -985,14 +848,14 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
             desc = String.format(desc, request.getServletPath());
         }
         String errorMsgStr = ERROR_PAGE_TEMPL;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", Integer.toString(status));
-        final String thisStatusMsg = this.statusMsg;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_MSG#", null == thisStatusMsg ? Integer.toString(status) : com.openexchange.java.Strings.quoteReplacement(thisStatusMsg));
-        errorMsgStr = errorMsgStr.replaceFirst("#STATUS_DESC#", com.openexchange.java.Strings.quoteReplacement(desc));
+        errorMsgStr =
+            errorMsgStr.replaceAll("#STATUS_CODE#", String.valueOf(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
+                "#STATUS_DESC#",
+                desc);
         synchronized (HEADER_DATE_FORMAT) {
             errorMsgStr = errorMsgStr.replaceFirst("#DATE#", HEADER_DATE_FORMAT.format(new Date(System.currentTimeMillis())));
         }
-        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getInstance().getVersionString());
+        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getVersionString());
         setContentType(new com.openexchange.java.StringAllocator("text/html; charset=").append(getCharacterEncoding()).toString());
         final byte[] errormessage = errorMsgStr.getBytes(Charsets.forName(getCharacterEncoding()));
         setContentLength(errormessage.length);
@@ -1010,23 +873,23 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
      * Gets the default error page.
      *
      * @return The default error page
+     * @throws IOException If an I/O error occurs
      */
-    public byte[] getErrorMessage() {
-        final int status = this.status;
-        String desc = STATUS_DESC.containsKey(status) ? STATUS_DESC.get(status) : ERR_DESC_NOT_AVAILABLE;
+    public byte[] getErrorMessage() throws IOException {
+        String desc = STATUS_DESC.containsKey(this.status) ? STATUS_DESC.get(this.status) : ERR_DESC_NOT_AVAILABLE;
         if (HttpServletResponse.SC_NOT_FOUND == status) {
             final HttpServletRequestImpl request = ajpProcessor.getRequest();
             desc = String.format(desc, request.getServletPath());
         }
         String errorMsgStr = ERROR_PAGE_TEMPL;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", Integer.toString(status));
-        final String statusMsg = this.statusMsg;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_MSG#", null == statusMsg ? Integer.toString(status) : com.openexchange.java.Strings.quoteReplacement(statusMsg));
-        errorMsgStr = errorMsgStr.replaceFirst("#STATUS_DESC#", com.openexchange.java.Strings.quoteReplacement(desc));
+        errorMsgStr =
+            errorMsgStr.replaceAll("#STATUS_CODE#", String.valueOf(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
+                "#STATUS_DESC#",
+                desc);
         synchronized (HEADER_DATE_FORMAT) {
             errorMsgStr = errorMsgStr.replaceFirst("#DATE#", HEADER_DATE_FORMAT.format(new Date(System.currentTimeMillis())));
         }
-        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getInstance().getVersionString());
+        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getVersionString());
         String encoding = getCharacterEncoding();
         if (null == encoding) {
             encoding = "UTF-8";
@@ -1042,7 +905,7 @@ public final class HttpServletResponseImpl implements HttpServletResponse {
         sendError(status, STATUS_MSGS.get(status));
     }
 
-    private Enumeration<?> makeEnumeration(final List<String> list) {
+    private Enumeration<String> makeEnumeration(final List<String> list) {
         return (new Enumeration<String>() {
 
             private final Iterator<String> iter = list.iterator();
