@@ -64,7 +64,7 @@ public final class AJPv13ServletInputStream extends ServletInputStream {
 
     private static final byte[] EMPTY_BYTES = new byte[0];
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(AJPv13ServletInputStream.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AJPv13ServletInputStream.class);
 
     private final AJPv13Connection ajpCon;
 
@@ -325,7 +325,7 @@ public final class AJPv13ServletInputStream extends ServletInputStream {
             ajpRequestHandler.processPackage();
             return (data != null);
         } catch (final AJPv13Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw new IOException(e.getMessage());
         }
     }
