@@ -56,7 +56,6 @@ import com.openexchange.ajp13.coyote.util.CharChunk;
 import com.openexchange.ajp13.coyote.util.MessageBytes;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
-import com.openexchange.log.Log;
 import com.openexchange.tools.codec.QuotedPrintable;
 
 /**
@@ -66,7 +65,7 @@ import com.openexchange.tools.codec.QuotedPrintable;
  */
 public final class AjpMessage {
 
-    private static final org.apache.commons.logging.Log log = Log.valueOf(com.openexchange.log.LogFactory.getLog(AjpMessage.class));
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(AjpMessage.class);
 
     // ------------------------------------------------------------ Constructor
 
@@ -261,10 +260,8 @@ public final class AjpMessage {
      */
     public void appendBytes(final byte[] b, final int off, final int numBytes) {
         if (pos + numBytes + 3 > buf.length) {
-            log.error("ajpmessage.overflow: numBytes=" + numBytes + ", pos=" + pos, new ArrayIndexOutOfBoundsException());
-            if (log.isDebugEnabled()) {
-                dump("Overflow/coBytes");
-            }
+            log.error("ajpmessage.overflow: numBytes={}, pos={}", numBytes, pos, new ArrayIndexOutOfBoundsException());
+            dump("Overflow/coBytes");
             return;
         }
         appendInt(numBytes);
@@ -312,10 +309,10 @@ public final class AjpMessage {
             try {
                 return QuotedPrintable.decodeString(sb.toString(), DEFAULT_ENCODING == null ? "UTF-8" : DEFAULT_ENCODING);
             } catch (final IOException e) {
-                log.warn(e.getMessage(), e);
+                log.warn("", e);
                 return sb.toString();
             } catch (final MessagingException e) {
-                log.warn(e.getMessage(), e);
+                log.warn("", e);
                 return sb.toString();
             }
         }
@@ -362,7 +359,7 @@ public final class AjpMessage {
     public int getBytes(final byte[] dest) {
         final int length = getInt();
         if (pos + length > buf.length) {
-            log.error("ajpmessage.read: length=" + length);
+            log.error("ajpmessage.read: length={}", length);
             return 0;
         }
 
@@ -405,15 +402,11 @@ public final class AjpMessage {
         len = getInt();
         // Verify message signature
         if ((mark != 0x1234) && (mark != 0x4142)) {
-            log.error("ajpmessage.invalid: mark=" + mark);
-            if (log.isDebugEnabled()) {
-                dump("In: ");
-            }
+            log.error("ajpmessage.invalid: mark={}", mark);
+            dump("In: ");
             return -1;
         }
-        if (log.isDebugEnabled()) {
-            log.debug("Received AJP message of length " + len + ". First payload byte is: " + buf[0]);
-        }
+        log.debug("Received AJP message of length {}. First payload byte is: {}", len, buf[0]);
         return len;
     }
 
@@ -421,23 +414,22 @@ public final class AjpMessage {
      * Dump the contents of the message, prefixed with the given String.
      */
     public void dump(final String msg) {
-        if (!log.isDebugEnabled()) {
-            return;
-        }
-        final com.openexchange.java.StringAllocator temp = new com.openexchange.java.StringAllocator(8192).append(msg).append('\n');
-        int max = pos;
-        if (len + 4 > pos) {
-            max = len + 4;
-        }
-        if (max > 1000) {
-            max = 1000;
-        }
+        if (log.isDebugEnabled()) {
+            final com.openexchange.java.StringAllocator temp = new com.openexchange.java.StringAllocator(8192).append(msg).append('\n');
+            int max = pos;
+            if (len + 4 > pos) {
+                max = len + 4;
+            }
+            if (max > 1000) {
+                max = 1000;
+            }
 
-        for (int j = 0; j < max; j += 16) {
-            hexLine(buf, j, len, temp);
-            temp.append('\n');
+            for (int j = 0; j < max; j += 16) {
+                hexLine(buf, j, len, temp);
+                temp.append('\n');
+            }
+            log.debug(temp.toString());
         }
-        log.debug(temp.toString());
     }
 
     // ------------------------------------------------------ Protected Methods
