@@ -66,6 +66,7 @@ import java.net.URLEncoder;
 import java.nio.charset.UnsupportedCharsetException;
 import java.util.List;
 import java.util.Locale;
+import java.util.Map;
 import java.util.Map.Entry;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
@@ -76,6 +77,7 @@ import javax.servlet.ServletInputStream;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletResponse;
+import org.apache.commons.codec.binary.Base64;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13RequestHandler;
 import com.openexchange.ajp13.AJPv13Response;
@@ -97,10 +99,7 @@ import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
-import com.openexchange.log.ForceLog;
-import com.openexchange.log.Log;
 import com.openexchange.log.LogProperties;
-import com.openexchange.log.Props;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 import com.openexchange.tools.exceptions.ExceptionUtils;
@@ -115,11 +114,7 @@ import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
  */
 public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
 
-    protected static final org.apache.commons.logging.Log LOG = Log.loggerFor(AjpProcessor.class);
-
-    private static final boolean TRACE = LOG.isTraceEnabled();
-
-    protected static final boolean DEBUG = LOG.isDebugEnabled();
+    protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AjpProcessor.class);
 
     private static final AtomicLong NUMBER = new AtomicLong();
 
@@ -297,6 +292,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
      */
     private volatile Thread thread;
 
+    /**
+     * The MDC map.
+     */
+    private volatile Map<String, String> mdcMap;
+
     /**
      * The scheduled keep-alive task.
      */
@@ -471,9 +471,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
          * Cause loading of HexUtils
          */
         final int foo = HexUtils.DEC[0];
-        if (TRACE) {
-            LOG.trace(Integer.valueOf(foo));
-        }
+        LOG.trace(Integer.toString(foo));
     }
 
     /**
@@ -528,7 +526,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
 
     @Override
     public boolean isLongRunning() {
-        return isEASPingCommand();
+        return isDriveRequest() || isEASPingCommand();
     }
 
     @Override
@@ -541,6 +539,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         return thread;
     }
 
+    @Override
+    public Map<String, String> getMdcMap() {
+        return mdcMap;
+    }
+
     @Override
     public String getThreadName() {
         return thread.getName();
@@ -648,9 +651,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         try {
             s.close();
         } catch (final Exception e) {
-            if (DEBUG) {
-                LOG.debug("Socket could not be closed. Probably due to a broken socket connection (e.g. broken pipe).", e);
-            }
+            LOG.debug("Socket could not be closed. Probably due to a broken socket connection (e.g. broken pipe).", e);
         }
     }
 
@@ -713,21 +714,17 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
          */
         error = false;
         final Thread thread = this.thread = Thread.currentThread();
-        final boolean logPropsEnabled = LogProperties.isEnabled();
+        mdcMap = LogProperties.getPropertyMap();
         while (started && !error && !thread.isInterrupted()) {
             /*
              * Parsing the request header
              */
-            if (logPropsEnabled) {
-                /*
-                 * Gather logging info
-                 */
-                final Props properties = LogProperties.getLogProperties();
-                properties.put(LogProperties.Name.AJP_THREAD_NAME, thread.getName());
-                properties.put(LogProperties.Name.AJP_REMOTE_PORT, Integer.valueOf(socket.getPort()));
-                properties.put(LogProperties.Name.AJP_REMOTE_ADDRESS, ForceLog.valueOf(socket.getInetAddress().getHostAddress()));
-            }
-            final boolean debug = LOG.isDebugEnabled();
+
+            /*
+             * Gather logging info
+             */
+            LogProperties.putProperties(LogProperties.Name.THREAD_ID, Long.toString(thread.getId()), LogProperties.Name.AJP_THREAD_NAME, thread.getName(), LogProperties.Name.AJP_REMOTE_PORT, Integer.valueOf(socket.getPort()), LogProperties.Name.AJP_REMOTE_ADDRESS, socket.getInetAddress().getHostAddress());
+
             try {
                 stage = Stage.STAGE_AWAIT;
                 listenerMonitor.incrementNumWaiting();
@@ -758,11 +755,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                  * not regular request processing
                  */
                 final int type = requestHeaderMessage.getByte();
-                if (debug) {
-                    final String ajpReqName =
-                        Constants.JK_AJP13_CPING_REQUEST == type ? "CPing" : (Constants.JK_AJP13_FORWARD_REQUEST == type ? "Forward-Request" : "unknown");
-                    LOG.debug("First " + ajpReqName + " AJP message successfully read from stream.");
-                }
+
                 if (type == Constants.JK_AJP13_CPING_REQUEST && 1 == requestHeaderMessage.getLen()) {
                     mainLock.lock();
                     try {
@@ -781,9 +774,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                      *
                      * Usually the servlet didn't read the previous request body
                      */
-                    if (debug) {
-                        LOG.debug("Unexpected message: " + type);
-                    }
+                    LOG.debug("Unexpected message: {}", type);
                     continue;
                 }
                 /*
@@ -800,11 +791,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 break;
             } catch (final Throwable t) {
                 // 400 - Bad Request
-                if (debug) {
-                    LOG.warn("400 - Bad Request: Parsing forward-request failed", t);
-                } else {
-                    LOG.warn("400 - Bad Request: Parsing forward-request failed");
-                }
+                LOG.warn("400 - Bad Request: Parsing forward-request failed", t);
                 response.setStatus(400);
                 error = true;
             } finally {
@@ -826,9 +813,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                      *
                      * Usually the servlet didn't read the previous request body
                      */
-                    if (debug) {
-                        requestHeaderMessage.dump("Invalid forward-request detected");
-                    }
+                    requestHeaderMessage.dump("Invalid forward-request detected");
                     continue;
                 } catch (final IllegalStateException stateException) {
                     /*-
@@ -849,14 +834,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                         final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(512);
                         sb.append("400 - Bad Request: Error preparing forward-request: ").append(t.getClass().getName());
                         sb.append(" message=").append(t.getMessage());
-                        if (Log.appendTraceToMessage()) {
-                            final String lineSeparator = System.getProperty("line.separator");
-                            sb.append(lineSeparator);
-                            appendStackTrace(t.getStackTrace(), sb, lineSeparator);
-                            LOG.warn(sb.toString());
-                        } else {
-                            LOG.warn(sb.toString(), t);
-                        }
+                        LOG.warn(sb.toString(), t);
                     }
                     response.setStatus(400);
                     error = true;
@@ -917,20 +895,15 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                         if (isConsiderXForwards) {
                             // Scheme
                             String protocol = request.getHeader(AJPv13Config.getProtocolHeader());
-                            if(!isValidProtocol(protocol)) {
-                                if (LOG.isDebugEnabled()) {
-                                    LOG.debug("Could not detect a valid protocol header value in " + protocol + ", falling back to default");
-                                }
-                                 protocol = request.getScheme();
+                            if (!isValidProtocol(protocol)) {
+                                LOG.debug("Could not detect a valid protocol header value in {}, falling back to default", protocol);
+                                protocol = request.getScheme();
                             }
                             // Remote address
                             String forHeaderValue = request.getHeader(AJPv13Config.getForHeader());
                             String remoteIP = IPTools.getRemoteIP(forHeaderValue, AJPv13Config.getKnownProxies());
                             if (remoteIP.isEmpty()) {
-                                if (LOG.isDebugEnabled()) {
-                                    forHeaderValue = forHeaderValue == null ? "" : forHeaderValue;
-                                    LOG.debug("Could not detect a valid remote ip in " + AJPv13Config.getForHeader() + ": [" + forHeaderValue + "], falling back to default");
-                                }
+                                LOG.debug("Could not detect a valid remote ip in {}: [{}], falling back to default", AJPv13Config.getForHeader(), forHeaderValue == null ? "" : forHeaderValue);
                                 remoteIP = request.getRemoteAddr();
                             }
                             // Apply values
@@ -962,12 +935,12 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                      */
                     final Throwable rootCause = e.getRootCause();
                     if (null != rootCause) {
-                        LOG.error(rootCause.getMessage(), rootCause);
+                        LOG.error("", rootCause);
                     }
                     /*
                      * Now log actual UploadServletException...
                      */
-                    LOG.error(e.getMessage(), e);
+                    LOG.error("", e);
                     /*
                      * ... and write bytes
                      */
@@ -998,9 +971,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                     /*
                      * Drop logging info
                      */
-                    if (logPropsEnabled) {
-                        LogProperties.removeLogProperties();
-                    }
+                    LogProperties.removeLogProperties();
                 }
             }
             /*
@@ -1011,9 +982,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                     finish();
                 } catch (final IOException e) {
                     // Lost connection
-                    if (debug) {
-                        LOG.debug("Lost connection to web server.", e);
-                    }
+                    LOG.debug("Lost connection to web server.", e);
                     error = true;
                 } catch (final Throwable t) {
                     ExceptionUtils.handleThrowable(t);
@@ -1040,15 +1009,14 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         input = null;
         output = null;
         this.thread = null;
+        mdcMap = null;
         this.socket = null;
         final long duration = System.currentTimeMillis() - st;
         listenerMonitor.addUseTime(duration);
         /*
          * Drop logging info
          */
-        if (logPropsEnabled) {
-            LogProperties.removeLogProperties();
-        }
+        LogProperties.removeLogProperties();
     }
 
     /**
@@ -1141,9 +1109,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                         output.write(flushMessageArray);
                         lastWriteAccess = System.currentTimeMillis();
                         output.flush();
-                        if (DEBUG) {
-                            LOG.debug("Performed keep-alive through a flush package.");
-                        }
+                        LOG.debug("Performed keep-alive through a flush package.");
                     } else {
                         /*
                          * Not committed, yet. Write an empty GET-BODY-CHUNK package.
@@ -1189,9 +1155,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                                 request.appendToBuffer(chunk);
                             }
                         }
-                        if (DEBUG) {
-                            LOG.debug("Performed keep-alive through an empty get-body-chunk package (and received requested chunk).");
-                        }
+                        LOG.debug("Performed keep-alive through an empty get-body-chunk package (and received requested chunk).");
                     }
                 } catch (final IOException e) {
                     // Set error flag
@@ -1287,14 +1251,55 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
 
     private static final String EAS_PING = "Ping";
 
+    private static final int EAS_COMMAND_CODE_PING = 18;
+
     /**
      * Checks for long-running EAS ping command, that is URI is equal to <code>"/Microsoft-Server-ActiveSync"</code> and request's
      * <code>"Cmd"</code> parameter equals <code>"Ping"</code>.
      *
      * @return <code>true</code> if EAS ping command is detected; otherwise <code>false</code>
      */
-    private boolean isEASPingCommand() {
-        return EAS_URI.equals(request.getRequestURI()) && EAS_PING.equals(request.getParameter(EAS_CMD));
+    private final boolean isEASPingCommand() {
+        if (EAS_URI.equals(request.getRequestURI())) {
+            if (EAS_PING.equals(request.getParameter(EAS_CMD))) {
+                return true;
+            }
+
+            /*-
+             * Check for possibly EAS base64-encoded query string
+             *
+             * Second byte reflects EAS command
+             */
+            final byte[] bytes = getBase64Bytes(request.getQueryString());
+            if (null != bytes && bytes.length > 2 && EAS_COMMAND_CODE_PING == bytes[1]) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    private final byte[] getBase64Bytes(final String queryString) {
+        if (Strings.isEmpty(queryString)) {
+            return null;
+        }
+
+        try {
+            final byte[] encodedBytes = Charsets.toAsciiBytes(queryString);
+            if (Base64.isBase64(encodedBytes)) {
+                return Base64.decodeBase64(encodedBytes);
+            }
+        } catch (final Exception e) {
+            LOG.warn("Could not check for EAS base64-encoded query string", e);
+        }
+
+        return null;
+    }
+
+    private static final String DRIVE_URI = "/ajax/drive";
+
+    private final boolean isDriveRequest() {
+        return DRIVE_URI.equals(request.getRequestURI());
     }
 
     /**
@@ -1405,7 +1410,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 }
             }
         }
-        if (LogProperties.isEnabled()) {
+        {
             /*
              * Gather logging info
              */
@@ -1413,7 +1418,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
             if (null != echoHeaderName) {
                 final String echoValue = request.getHeader(echoHeaderName);
                 if (null != echoValue) {
-                    LogProperties.putLogProperty(LogProperties.Name.AJP_REQUEST_ID, echoValue);
+                    LogProperties.putProperty(LogProperties.Name.AJP_REQUEST_ID, echoValue);
                 }
             }
         }
@@ -1475,16 +1480,20 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 request.setQueryString(queryString);
                 {
                     parseQueryString(queryString);
-                    if (DEBUG && isEASPingCommand()) {
-                        LOG.debug("Incoming long-running EAS ping request.");
+                    if (LOG.isDebugEnabled()) {
+                        if (isEASPingCommand()) {
+                            LOG.debug("Incoming long-running EAS ping request.");
+                        } else if (isDriveRequest()) {
+                            LOG.debug("Incoming long-running OX Drive request.");
+                        }
                     }
                 }
             }
                 break;
             case Constants.SC_A_JVM_ROUTE: {
                 final String jvmRoute = requestHeaderMessage.getString(temp);
-                if (DEBUG && !AJPv13Config.getJvmRoute().equals(jvmRoute)) {
-                    LOG.debug("JVM route mismatch. Expected \"" + AJPv13Config.getJvmRoute() + "\", but is \"" + jvmRoute + "\".");
+                if (!AJPv13Config.getJvmRoute().equals(jvmRoute)) {
+                    LOG.debug("JVM route mismatch. Expected \"{}\", but is \"{}\".", AJPv13Config.getJvmRoute(), jvmRoute);
                 }
                 request.setInstanceId(jvmRoute);
             }
@@ -1578,20 +1587,15 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         setServletInstance(request.getRequestURI());
         final String serverName = request.getServerName();
         {
-            final Props properties = LogProperties.getLogProperties();
-            if (LogProperties.isEnabled()) {
-                properties.put(LogProperties.Name.AJP_REQUEST_URI, request.getRequestURI());
-                properties.put(LogProperties.Name.AJP_SERVLET_PATH, request.getServletPath());
-                properties.put(LogProperties.Name.AJP_PATH_INFO, request.getPathInfo());
-                final String action = request.getParameter("action");
-                if (null != action) {
-                    properties.put(LogProperties.Name.AJAX_ACTION, action);
-                }
+            LogProperties.putProperties(LogProperties.Name.AJP_REQUEST_URI, request.getRequestURI(), LogProperties.Name.AJP_SERVLET_PATH, request.getServletPath(), LogProperties.Name.AJP_PATH_INFO, request.getPathInfo());
+            final String action = request.getParameter("action");
+            if (null != action) {
+                LogProperties.putProperty(LogProperties.Name.AJAX_ACTION, action);
             }
-            properties.put(LogProperties.Name.AJP_REQUEST_IP, request.getRemoteAddr());
-            properties.put(LogProperties.Name.AJP_SERVER_NAME, serverName);
+            LogProperties.putProperty(LogProperties.Name.AJP_REQUEST_IP, request.getRemoteAddr());
+            LogProperties.putProperty(LogProperties.Name.AJP_SERVER_NAME, serverName);
             final String userAgent = request.getHeader("User-Agent");
-            properties.put(LogProperties.Name.GRIZZLY_USER_AGENT, null == userAgent ? "<unknown>" : userAgent);
+            LogProperties.putProperty(LogProperties.Name.GRIZZLY_USER_AGENT, null == userAgent ? "<unknown>" : userAgent);
         }
         /*
          * Set proper JSESSIONID cookie and pre-create associated HTTP session
@@ -1676,7 +1680,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                     // Invalid character
                     error = true;
                     // 400 - Bad request
-                    LOG.warn("400 - Bad Request: Invalid character in server name: \"" + host + '"');
+                    LOG.warn("400 - Bad Request: Invalid character in server name: \"{}{}", host, '"');
                     response.setStatus(400);
                     break;
                 }
@@ -1698,17 +1702,14 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
      */
     private void parseQueryString(final String queryStr) {
         final String[] paramsNVPs = PATTERN_SPLIT.split(queryStr, 0);
-        String charEnc = request.getCharacterEncoding();
-        if (null == charEnc) {
-            charEnc = AJPv13Config.getServerProperty(Property.DefaultEncoding);
-        }
+        final String defaultCharEnc = AJPv13Config.getServerProperty(Property.DefaultEncoding);
         for (String paramsNVP : paramsNVPs) {
             paramsNVP = paramsNVP.trim();
             if (paramsNVP.length() > 0) {
                 // Look-up character '='
                 final int pos = paramsNVP.indexOf('=');
                 if (pos >= 0) {
-                    request.setParameter(paramsNVP.substring(0, pos), decodeUrl(paramsNVP.substring(pos + 1), charEnc));
+                    request.setParameter(paramsNVP.substring(0, pos), decodeUrl(paramsNVP.substring(pos + 1), defaultCharEnc));
                 } else {
                     request.setParameter(paramsNVP, "");
                 }
@@ -1722,25 +1723,31 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
      * @param requestURI The request URI
      */
     private void setServletInstance(final String requestURI) {
-        String charEnc = request.getCharacterEncoding();
-        if (null == charEnc) {
-            charEnc = AJPv13Config.getServerProperty(Property.DefaultEncoding);
-        }
-        final String decodedRequestURI = AJPv13Utility.decodeUrl(requestURI, charEnc);
-        /*
-         * Remove leading slash character
-         */
-        final String path = decodedRequestURI.length() > 1 ? removeFromPath(decodedRequestURI, '/') : decodedRequestURI;
-        /*
-         * Lookup path in available servlet paths
-         */
         if (servletId.length() > 0) {
             servletId.setLength(0);
         }
+        String reqURI = requestURI;
+        // Remove leading slash character
+        String path = reqURI.length() > 1 ? removeFromPath(reqURI, '/') : reqURI;
         HttpServlet servlet = HttpServletManager.getServlet(path, servletId);
         if (servlet == null) {
-            servlet = new HttpErrorServlet("No servlet bound to path/alias: " + AJPv13Utility.urlEncode(decodedRequestURI, charEnc));
+            // Retry look-up using decoded form
+            final String defaultCharEnc = AJPv13Config.getServerProperty(Property.DefaultEncoding);
+            if (servletId.length() > 0) {
+                servletId.setLength(0);
+            }
+            reqURI = AJPv13Utility.decodeUrl(requestURI, defaultCharEnc);
+            // Remove leading slash character
+            path = reqURI.length() > 1 ? removeFromPath(reqURI, '/') : reqURI;
+            servlet = HttpServletManager.getServlet(path, servletId);
+            if (servlet == null) {
+                servlet = new HttpErrorServlet("No servlet bound to path/alias: " + AJPv13Utility.urlEncode(reqURI, defaultCharEnc));
+            }
+        } else {
+            final String defaultCharEnc = AJPv13Config.getServerProperty(Property.DefaultEncoding);
+            reqURI = AJPv13Utility.decodeUrl(reqURI, defaultCharEnc);
         }
+        path = null; // Not used anymore
         this.servlet = servlet;
         // servletId = pathStorage.length() > 0 ? pathStorage.toString() : null;
         if (servletId.length() > 0) {
@@ -1761,7 +1768,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                 /*
                  * Set complete request URI as path info
                  */
-                request.setPathInfo(decodedRequestURI);
+                request.setPathInfo(reqURI);
             } else {
                 /*
                  * The path starts with a "/" character and includes either the servlet name or a path to the servlet, but does not include
@@ -1772,8 +1779,8 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                  * Set path info: The extra path information follows the servlet path but precedes the query string and will start with a
                  * "/" character.
                  */
-                if ((decodedRequestURI.length() > servletPathLen) /* && requestURI.startsWith(servletPath) */) {
-                    request.setPathInfo(decodedRequestURI.substring(servletPathLen));
+                if ((reqURI.length() > servletPathLen) /* && requestURI.startsWith(servletPath) */) {
+                    request.setPathInfo(reqURI.substring(servletPathLen));
                 } else {
                     request.setPathInfo(null);
                 }
@@ -1818,9 +1825,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             /*
                              * Different JVM route detected -> Discard
                              */
-                            if (DEBUG) {
-                                LOG.debug(new com.openexchange.java.StringAllocator("\n\tDifferent JVM route detected. Removing JSESSIONID cookie: ").append(id));
-                            }
+                            LOG.debug("\n\tDifferent JVM route detected. Removing JSESSIONID cookie: {}", id);
                             current.setPath("/");
                             final String domain = extractDomainValue(id);
                             if (null != domain) {
@@ -1844,9 +1849,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             /*
                              * Invalid cookie
                              */
-                            if (DEBUG) {
-                                LOG.debug(new com.openexchange.java.StringAllocator("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
-                            }
+                            LOG.debug("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: {}", current.getValue());
                             current.setPath("/");
                             final String domain = extractDomainValue(id);
                             if (null != domain) {
@@ -1864,7 +1867,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             continue NextCookie;
                         }
                         jsessionIDCookie = current;
-                        LogProperties.putLogProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
+                        LogProperties.putProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
                         jsessionIDCookie.setSecure(request.isSecure() || (forceHttps && !Cookies.isLocalLan(request)));
                         httpSessionCookie = jsessionIDCookie;
                         httpSessionJoined = true;
@@ -1876,9 +1879,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             /*
                              * But this host defines a JVM route
                              */
-                            if (DEBUG) {
-                                LOG.debug(new com.openexchange.java.StringAllocator("\n\tMissing JVM route in JESSIONID cookie").append(current.getValue()));
-                            }
+                            LOG.debug("\n\tMissing JVM route in JESSIONID cookie{}", current.getValue());
                             current.setPath("/");
                             final String domain = extractDomainValue(id);
                             if (null != domain) {
@@ -1902,9 +1903,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             /*
                              * Invalid cookie
                              */
-                            if (DEBUG) {
-                                LOG.debug(new com.openexchange.java.StringAllocator("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
-                            }
+                            LOG.debug("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: {}", current.getValue());
                             current.setPath("/");
                             final String domain = extractDomainValue(id);
                             if (null != domain) {
@@ -1922,7 +1921,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                             continue NextCookie;
                         }
                         jsessionIDCookie = current;
-                        LogProperties.putLogProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
+                        LogProperties.putProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
                         jsessionIDCookie.setSecure(request.isSecure() || (forceHttps && !Cookies.isLocalLan(request)));
                         httpSessionCookie = jsessionIDCookie;
                         httpSessionJoined = true;
@@ -1959,7 +1958,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         }
         final String id = jsessionIDVal.toString();
         final Cookie jsessionIDCookie = newJsessionIdCookie(id, domain);
-        LogProperties.putLogProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
+        LogProperties.putProperty(LogProperties.Name.AJP_HTTP_SESSION, id);
         jsessionIDCookie.setSecure(request.isSecure() || (forceHttps && !Cookies.isLocalLan(request)));
         httpSessionCookie = jsessionIDCookie;
         httpSessionJoined = false;
@@ -1995,7 +1994,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
             join = false;
         }
         final Cookie jsessionIDCookie = newJsessionIdCookie(jsessionIdVal, domain);
-        LogProperties.putLogProperty(LogProperties.Name.AJP_HTTP_SESSION, jsessionIdVal);
+        LogProperties.putProperty(LogProperties.Name.AJP_HTTP_SESSION, jsessionIdVal);
         jsessionIDCookie.setSecure(request.isSecure() || (forceHttps && !Cookies.isLocalLan(request)));
         httpSessionCookie = jsessionIDCookie;
         httpSessionJoined = join;
@@ -2474,9 +2473,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                     ajpProcessor.action(ActionCode.CLIENT_PING, null);
                 }
             } catch (final Exception e) {
-                if (DEBUG) {
-                    LOG.error("AJP KEEP-ALIVE failed.", e);
-                }
+                 LOG.error("AJP KEEP-ALIVE failed.", e);
             }
         }
 
