@@ -55,7 +55,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.TreeMap;
-import com.openexchange.log.Log;
 
 /**
  * {@link StringCache}
@@ -64,7 +63,7 @@ import com.openexchange.log.Log;
  */
 public final class StringCache {
 
-    private static final org.apache.commons.logging.Log log = Log.valueOf(com.openexchange.log.LogFactory.getLog(StringCache.class));
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(StringCache.class);
 
     /**
      * Enabled ?
@@ -225,7 +224,6 @@ public final class StringCache {
                     // case the cache must be created, or we just update the count for
                     // the string
                     if (bcCount > trainThreshold) {
-                        final long t1 = System.currentTimeMillis();
                         // Sort the entries according to occurrence
                         final TreeMap tempMap = new TreeMap();
                         final Iterator entries = bcStats.keySet().iterator();
@@ -273,10 +271,6 @@ public final class StringCache {
                         bcCount = 0;
                         bcStats.clear();
                         bcCache = tempbcCache;
-                        if (log.isDebugEnabled()) {
-                            final long t2 = System.currentTimeMillis();
-                            log.debug("ByteCache generation time: " + (t2 - t1) + "ms");
-                        }
                     } else {
                         bcCount++;
                         // Allocate new ByteEntry for the lookup
@@ -336,7 +330,6 @@ public final class StringCache {
                     // case the cache must be created, or we just update the count for
                     // the string
                     if (ccCount > trainThreshold) {
-                        final long t1 = System.currentTimeMillis();
                         // Sort the entries according to occurrence
                         final TreeMap tempMap = new TreeMap();
                         final Iterator entries = ccStats.keySet().iterator();
@@ -384,10 +377,6 @@ public final class StringCache {
                         ccCount = 0;
                         ccStats.clear();
                         ccCache = tempccCache;
-                        if (log.isDebugEnabled()) {
-                            final long t2 = System.currentTimeMillis();
-                            log.debug("CharCache generation time: " + (t2 - t1) + "ms");
-                        }
                     } else {
                         ccCount++;
                         // Allocate new CharEntry for the lookup
